fluidfft.fft3d.operators
========================

.. automodule:: fluidfft.fft3d.operators

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_simple_3d_mpi_method
      get_simple_3d_seq_method
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      OperatorsPseudoSpectral3D
   
   

   
   
   